summaryrefslogtreecommitdiffstats
path: root/src/mbedTLS++/X509Cert.cpp
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/mbedTLS++/X509Cert.cpp (renamed from src/PolarSSL++/X509Cert.cpp)10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/PolarSSL++/X509Cert.cpp b/src/mbedTLS++/X509Cert.cpp
index ed65639a5..1e51dd2b7 100644
--- a/src/PolarSSL++/X509Cert.cpp
+++ b/src/mbedTLS++/X509Cert.cpp
@@ -1,7 +1,7 @@
-
+
// X509Cert.cpp
// Implements the cX509Cert class representing a wrapper over X509 certs in PolarSSL
#include "Globals.h"
#include "X509Cert.h"
@@ -12,7 +12,7 @@
cX509Cert::cX509Cert(void)
{
- x509_crt_init(&m_Cert);
+ mbedtls_x509_crt_init(&m_Cert);
}
@@ -21,7 +21,7 @@ cX509Cert::cX509Cert(void)
cX509Cert::~cX509Cert()
{
- x509_crt_free(&m_Cert);
+ mbedtls_x509_crt_free(&m_Cert);
}
@@ -30,7 +30,7 @@ cX509Cert::~cX509Cert()
int cX509Cert::Parse(const void * a_CertContents, size_t a_Size)
{
- return x509_crt_parse(&m_Cert, reinterpret_cast<const unsigned char *>(a_CertContents), a_Size);
+ return mbedtls_x509_crt_parse(&m_Cert, reinterpret_cast<const unsigned char *>(a_CertContents), a_Size);
}
@@ -1,7 +1,7 @@
// X509Cert.cpp
-// Implements the cX509Cert class representing a wrapper over X509 certs in PolarSSL
+// Implements the cX509Cert class representing a wrapper over X509 certs in mbedTLS
#include "Globals.h"
#include "X509Cert.h"